# -*- coding: utf-8 -*-
"""
capivara
~~~~~~~~
:copyright: (c) 2016 by Raphael Amorim.
"""
from .api import init

__title__ = 'capivara'
__version__ = '0.0.1'
__author__ = 'Raphael Amorim'
__license__ = 'Apache License 2.0'
__copyright__ = 'Copyright 2016 Raphael Amorim'
